- Use the following template for the `description` of a `Bug` ticket. For example
  in English:

  ```jira
  <description of the bug>
  ‍
  h4.‍ Steps to Reproduce
  - Step 1
  - Step 2
  - Step 3
  - Step 4

  ‍h4. Actual Behavior‍
  [Describe the issue in detail, including what is happening and where]

  ‍
  h4‍. Expected Behavior

  [Describe what should be happening instead]

  ‍
  ‍h4. Impacted

  [Provide details on which customers are impacted by this issue, and the potential business impact]

  ‍
  ‍h4. Software Impacted

  [Identify which part of the software is impacted by the bug (e.g. Login, Dashboard, etc.)]
  ```
